@@ -8,7 +8,8 @@
 #' @param ft a flextable
 #' @param start_col a vector specifying the starting column to write to.
 #' @param start_row a vector specifying the starting row to write to.
-#' @param dims Spreadsheet dimensions that will determine start_col and start_row: "A1", "A1:B2", "A:B"
+#' @param dims Spreadsheet dimensions that will determine start_col and
+#' start_row: "A1", "A1:B2", "A:B"
 #' @param offset_caption_rows number of rows to offset the caption by
 #'
 #' @return an openxlsx2 workbook
@@ -18,9 +19,9 @@
 #'
 #' @examples
 #'
-#' if(requireNamespace("flextable", quietly = TRUE)) {
+#' if (requireNamespace("flextable", quietly = TRUE)) {
 #'   # Create a flextable
-#'   ft <- flextable::as_flextable(table(mtcars[,c("am","cyl")]))
+#'   ft <- flextable::as_flextable(table(mtcars[, c("am", "cyl")]))
 #'
 #'   # Create a workbook
 #'   wb <- openxlsx2::wb_workbook()$add_worksheet("mtcars")
@@ -31,7 +32,7 @@
 #'   # Workbook can now be saved wb$save(),
 #'   # opened wb$open() - or removed
 #'   rm(wb)
-#'  }
+#' }
 #'
 wb_add_flextable <- function(wb,
                              sheet = openxlsx2::current_sheet(),
@@ -44,7 +45,7 @@ wb_add_flextable <- function(wb,
   stopifnot("wbWorkbook" %in% class(wb))
 
   sheet_validated <- wb$validate_sheet(sheet)
-  if(is.na(sheet_validated)) {
+  if (is.na(sheet_validated)) {
     stop("Sheet '", sheet, "' does not exist!")
   }
   sheet <- sheet_validated
@@ -57,36 +58,44 @@ wb_add_flextable <- function(wb,
     offset_cols <- min(dims[[1]]) - 1
     offset_rows <- min(dims[[2]]) - 1
   } else {
-    stopifnot(is.numeric(start_col),
-              start_col >= 1,
-              as.integer(start_col) == start_col,
-              length(start_col) == 1)
-    stopifnot(is.numeric(start_row) &&
-                start_row >= 1 &&
-                as.integer(start_col) == start_col,
-              length(start_col) == 1)
+    stopifnot(
+      is.numeric(start_col),
+      start_col >= 1,
+      as.integer(start_col) == start_col,
+      length(start_col) == 1
+    )
+    stopifnot(
+      is.numeric(start_row) &&
+        start_row >= 1 &&
+        as.integer(start_col) == start_col,
+      length(start_col) == 1
+    )
 
     offset_cols <- start_col - 1
     offset_rows <- start_row - 1
   }
 
   # ignore offset if there is no caption
-  if(length(ft$caption$value) == 0) {
+  if (length(ft$caption$value) == 0) {
     offset_caption_rows <- 0L
   }
 
   wb <- wb$clone()
 
   df_style <- ft_to_style_tibble(ft,
-                                 offset_rows=offset_rows,
-                                 offset_cols=offset_cols,
-                                 offset_caption_rows=offset_caption_rows)
+    offset_rows = offset_rows,
+    offset_cols = offset_cols,
+    offset_caption_rows = offset_caption_rows
+  )
 
   # Apply styles & add content
-  if(length(ft$caption$value) > 0)
-    wb_add_caption(wb, sheet = sheet, ft = ft,
-                   offset_rows=offset_rows,
-                   offset_cols=offset_cols)
+  if (length(ft$caption$value) > 0) {
+    wb_add_caption(wb,
+      sheet = sheet, ft = ft,
+      offset_rows = offset_rows,
+      offset_cols = offset_cols
+    )
+  }
 
   df_style <- wb_apply_merge(wb, sheet, df_style)
   wb_apply_border(wb, sheet, df_style)
@@ -98,6 +107,3 @@ wb_add_flextable <- function(wb,
 
   return(wb)
 }
-
-
-
